@@ -2,14 +2,21 @@ package Chemistry::OpenSMILES;
 
 use strict;
 use warnings;
+use 5.0100;
 
-our $VERSION = '0.1.2'; # VERSION
 # ABSTRACT: OpenSMILES format reader
+our $VERSION = '0.1.3'; # VERSION
 
 1;
 
 __END__
 
+=pod
+
+=head1 NAME
+
+Chemistry::OpenSMILES - OpenSMILES format reader
+
 =head1 SYNOPSIS
 
     use Chemistry::OpenSMILES::Parser;
@@ -59,7 +66,7 @@ it before attempting reading with Chemistry::OpenSMILES::Parser.
 
 perl(1)
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Andrius Merkys, E<lt>merkys@cpan.orgE<gt>
 
